kappa library

Mixins

EntityConvertible<Model, Entity extends BaseEntity>
A mixin that provides conversion methods between entity and model objects.
InjectableServiceMixin

Constants

ApiCacheCollectionSchema → const CollectionSchema<ApiCacheCollection>

Properties

injector → GetIt
final

Exceptions / Errors

BaseException
DatabaseException
A custom exception class for database errors.
LocalStorageException
NetworkException
This class extends Equatable and implements Exception. It contains a message and a statusCode property. The message property contains the error message and the statusCode property contains the HTTP status code of the response.